%% code to load wav-files and display frequency response

clc;
more off;

graphics_toolkit('gnuplot');
pkg load signal

% load wave file
filename = 'THC_E906.wav';
[y, fs] = audioread(filename);
y = y';

ly = length(y);           % length of audio file
t = ly/fs;                % time of audio file

t_eval = t;               % evalutation time, t for complete length 
l_eval = t_eval*fs;       

fn = fs/2;                % Nyquist frequency
df = fs/l_eval;           % frequency resolution

%% frequency domain
x_fn = 0:df:fn-df;                                            % frequency vector
H = fft(y(1,1:l_eval));                                       % FFT
H_single = [H(1,1)/l_eval H(1,2:l_eval/2)/(l_eval/2)];        % single sided spectrum
H_norm = H_single./max(H_single);                             % normalize to max
ampl_dB = 20*log10(abs(H_norm));                              % amplitude log

%% plot
t_plot = 0:1/fs:t_eval-1/fs;
figure(1);
plot(t_plot, y(1,1:l_eval), 'linewidth', 2);
xlabel('time in seconds');
ylabel('amplitude');
grid on;
title({['Impulse response ' filename]}, 'interpreter', 'none');

% variables for plots versus frequency
f_ticks = [linspace(20, 90, 8) linspace(100, 900, 9) linspace(1e3, 9e3, 9) linspace(1e4, 2e4, 2)];
f_ticklabels = cell(1, length(f_ticks));
f_ticklabels(1,:) = ' ';
f_ticklabels(1,1) = '20';
f_ticklabels(1,9) = '100';
f_ticklabels(1,18) = '1000';
f_ticklabels(1,27) = '10000';
f_ticklabels(1,end) = '20000';

figure(2);
semilogx(x_fn(2:end), ampl_dB(2:end), 'linewidth', 2);
grid on;
xlim([20 20e3]);
set(gca, 'xtickmode', 'manual');
set(gca, 'xtick', f_ticks);
set(gca, 'xticklabelmode', 'manual');
set(gca, 'xticklabel', f_ticklabels);
ylim([-35 5]);
set(gca, 'ytickmode', 'manual');
set(gca, 'ytick', min(ylim):5:max(ylim));
xlabel('frequency in Hz');
ylabel('amplitude in dB');
title({['Frequency response ' filename]}, 'interpreter', 'none');